@@ -27,7 +27,9 @@ class Circuit:
         self._component_list = []
         self._reference_manager = ReferenceManager()
         self._annotations = []  # Store TextProperty, TextBox, etc.
-        self._ref_mapping = {}  # Track prefix -> final ref mappings for source rewriting
+        self._ref_mapping = (
+            {}
+        )  # Track prefix -> final ref mappings for source rewriting
         self._circuit_func = None  # Store reference to the @circuit decorated function
 
     def validate_reference(self, ref: str) -> bool:
@@ -68,7 +70,8 @@ class Circuit:
             from .net import Net
 
             for net_data in json_data["nets"]:
-                net = Net(net_data.get("name", "unnamed"))
+                # Use from_dict to preserve all Net attributes
+                net = Net.from_dict(net_data)
                 circuit._nets[net.name] = net
 
         # Add subcircuits recursively
@@ -241,7 +244,7 @@ class Circuit:
             context_logger.debug(
                 "No circuit function reference available",
                 component="CIRCUIT",
-                circuit_name=self.name
+                circuit_name=self.name,
             )
             return None
 
@@ -249,20 +252,20 @@ class Circuit:
             source_file = inspect.getfile(self._circuit_func)
 
             # Check for special cases where source isn't available
-            if source_file == '<stdin>' or source_file == '<string>':
+            if source_file == "<stdin>" or source_file == "<string>":
                 context_logger.warning(
                     "Circuit defined in REPL/exec environment, source file not available",
                     component="CIRCUIT",
-                    circuit_name=self.name
+                    circuit_name=self.name,
                 )
                 return None
 
             # Check for frozen applications (PyInstaller, etc)
-            if getattr(inspect.sys, 'frozen', False):
+            if getattr(inspect.sys, "frozen", False):
                 context_logger.warning(
                     "Running in frozen application, source file not available",
                     component="CIRCUIT",
-                    circuit_name=self.name
+                    circuit_name=self.name,
                 )
                 return None
 
@@ -273,7 +276,7 @@ class Circuit:
                     "Source file no longer exists",
                     component="CIRCUIT",
                     circuit_name=self.name,
-                    source_file=str(path)
+                    source_file=str(path),
                 )
                 return None
 
@@ -284,7 +287,7 @@ class Circuit:
                 "Could not determine source file",
                 component="CIRCUIT",
                 circuit_name=self.name,
-                error=str(e)
+                error=str(e),
             )
             return None
 
@@ -302,9 +305,7 @@ class Circuit:
         """
         if not self._ref_mapping:
             context_logger.debug(
-                "No ref mapping to apply",
-                component="CIRCUIT",
-                circuit_name=self.name
+                "No ref mapping to apply", component="CIRCUIT", circuit_name=self.name
             )
             return False
 
@@ -316,7 +317,7 @@ class Circuit:
                 component="CIRCUIT",
                 circuit_name=self.name,
                 source_file=str(source_file),
-                ref_mapping=self._ref_mapping
+                ref_mapping=self._ref_mapping,
             )
 
             rewriter = SourceRefRewriter(source_file, self._ref_mapping)
@@ -327,13 +328,13 @@ class Circuit:
                     "Source file updated successfully",
                     component="CIRCUIT",
                     circuit_name=self.name,
-                    refs_updated=len(self._ref_mapping)
+                    refs_updated=len(self._ref_mapping),
                 )
             else:
                 context_logger.debug(
                     "Source file unchanged (no modifications needed)",
                     component="CIRCUIT",
-                    circuit_name=self.name
+                    circuit_name=self.name,
                 )
 
             return success
@@ -344,7 +345,7 @@ class Circuit:
                 component="CIRCUIT",
                 circuit_name=self.name,
                 source_file=str(source_file),
-                error=str(e)
+                error=str(e),
             )
             # Don't raise - source rewriting failure shouldn't break project generation
             return False
@@ -609,10 +610,11 @@ class Circuit:
         project_name: str,
         generate_pcb: bool = True,
         force_regenerate: bool = False,
-        placement_algorithm: str = "connection_centric",
+        placement_algorithm: str = "hierarchical",
         draw_bounding_boxes: bool = False,
         generate_ratsnest: bool = True,
         update_source_refs: Optional[bool] = None,
+        preserve_user_components: bool = False,
     ) -> Dict[str, Any]:
         """
         Generate a complete KiCad project (schematic + PCB) from this circuit.
@@ -625,13 +627,16 @@ class Circuit:
             project_name: Name of the KiCad project and directory to create
             generate_pcb: Whether to generate PCB in addition to schematic (default: True)
             force_regenerate: Force regeneration of existing files, losing manual edits (default: False)
-            placement_algorithm: Component placement algorithm to use (default: "connection_centric")
+            placement_algorithm: Component placement algorithm to use (default: "hierarchical")
             draw_bounding_boxes: Whether to draw visual bounding boxes around components (default: False)
             generate_ratsnest: Whether to generate ratsnest connections in PCB (default: True)
             update_source_refs: Whether to update source file with finalized refs.
                                None (default): Auto-update unless force_regenerate=True
                                True: Always update source file
                                False: Never update source file
+            preserve_user_components: Keep components in KiCad that don't exist in Python (default: False)
+                                     False: Python is source of truth - delete components not in Python
+                                     True: Preserve all components in KiCad, even if not in Python
 
         Returns:
             dict: Result dictionary containing:
@@ -647,8 +652,8 @@ class Circuit:
             >>> print(f"KiCad project: {result['project_path']}")
         """
         try:
-            from ..kicad.config import get_recommended_generator
             from .. import print_version_info
+            from ..kicad.config import get_recommended_generator
 
             # Print version information for debugging
             print_version_info()
@@ -672,7 +677,7 @@ class Circuit:
                     context_logger.debug(
                         "Source file not available, skipping ref update",
                         component="CIRCUIT",
-                        circuit_name=self.name
+                        circuit_name=self.name,
                     )
 
             # Create output directory with the project name
@@ -692,10 +697,48 @@ class Circuit:
             # Use legacy system for positioning/hierarchy, modern API for file writing
             from ..kicad.sch_gen.main_generator import SchematicGenerator
 
-            context_logger.info("Using hybrid approach: legacy positioning + modern kicad-sch-api file writing", component="CIRCUIT")
+            context_logger.info(
+                "Using hybrid approach: legacy positioning + modern kicad-sch-api file writing",
+                component="CIRCUIT",
+            )
+
+            # Determine project base name for file generation
+            # Check for existing .kicad_pro files in output directory
+            existing_projects = list(output_path.glob("*.kicad_pro"))
+
+            if len(existing_projects) > 1:
+                # Multiple projects - error out
+                project_names = [p.stem for p in existing_projects]
+                raise ValueError(
+                    f"Multiple KiCad projects found in '{output_path}': {project_names}. "
+                    f"Please specify which project to update or clean the directory."
+                )
+            elif len(existing_projects) == 1:
+                # Exactly one project - use its base name for regeneration
+                project_base_name = existing_projects[0].stem
+                context_logger.info(
+                    f"Detected existing KiCad project: {project_base_name}",
+                    component="CIRCUIT",
+                )
+                # Validate folder name matches project base name
+                if output_path.name != project_base_name:
+                    context_logger.warning(
+                        f"Folder name '{output_path.name}' doesn't match project '{project_base_name}'. "
+                        f"Using circuit name for file generation.",
+                        component="CIRCUIT",
+                    )
+                    # Use circuit name for file generation, not folder name
+                    project_base_name = self.name
+            else:
+                # No existing project - use circuit name for KiCad files
+                project_base_name = self.name
+                context_logger.info(
+                    f"No existing project found, using circuit name: {project_base_name}",
+                    component="CIRCUIT",
+                )
 
             # Create JSON netlist in project directory (canonical format)
-            json_path = output_path / f"{output_path.name}.json"
+            json_path = output_path / f"{project_base_name}.json"
             self.generate_json_netlist(str(json_path))
 
             context_logger.info(
@@ -704,8 +747,13 @@ class Circuit:
                 json_path=str(json_path),
             )
 
-            # Create schematic generator that outputs directly to the project directory
-            generator = SchematicGenerator(str(output_path.parent), project_name)
+            # Create schematic generator
+            # Pass output_path.parent as output_dir and project_base_name as project_name
+            # But we need to change how SchematicGenerator uses project_dir
+            # For now, pass the full path and update how project_dir is computed
+            generator = SchematicGenerator(str(output_path), project_base_name)
+            # Override project_dir since output_path is already the full project directory
+            generator.project_dir = Path(str(output_path)).resolve()
 
             # Generate the complete project using the JSON file
             # Legacy system handles placement, modern API handles file writing via write_schematic_file
@@ -717,6 +765,7 @@ class Circuit:
                 force_regenerate=force_regenerate,
                 draw_bounding_boxes=draw_bounding_boxes,
                 generate_ratsnest=generate_ratsnest,
+                preserve_user_components=preserve_user_components,
             )
 
             if result.get("success", True):  # Default to success if not specified
@@ -766,6 +815,420 @@ class Circuit:
                 "error": error_msg,
             }
 
+    def generate_bom(
+        self,
+        output_file: Optional[str] = None,
+        project_name: Optional[str] = None,
+        fields: Optional[str] = None,
+        labels: Optional[str] = None,
+        group_by: Optional[str] = None,
+        exclude_dnp: bool = False,
+    ) -> Dict[str, Any]:
+        """
+        Generate a Bill of Materials (BOM) from this circuit as a CSV file.
+
+        This method creates a KiCad project if one doesn't already exist, then
+        exports the schematic to a CSV BOM file using kicad-cli.
+
+        Args:
+            output_file: Path where CSV BOM should be written. If not provided,
+                        defaults to {project_name}/{project_name}.csv
+            project_name: Name of the KiCad project directory. If not provided,
+                         defaults to the circuit name. Required if output_file is provided
+                         but needs a project.
+            fields: Comma-separated fields to export from schematic. If not specified,
+                   KiCad will export default fields (Refs, Value, Footprint, etc.)
+            labels: Comma-separated column headers for the BOM. Must match the number
+                   of fields if fields are specified.
+            group_by: Field to group references by when exporting. Common values:
+                     "Value" (group by component value), "Footprint", etc.
+            exclude_dnp: If True, exclude "Do not populate" components from BOM
+
+        Returns:
+            dict: Result dictionary containing:
+                - success (bool): True if BOM was successfully generated
+                - file (Path): Path to the generated CSV file
+                - component_count (int): Number of components in the BOM
+                - project_path (Path): Path to the KiCad project directory
+                - error (str, optional): Error message if generation failed
+
+        Example:
+            >>> circuit = led_blinker()
+            >>> result = circuit.generate_bom(project_name="led_blinker")
+            >>> print(f"BOM exported to: {result['file']}")
+            >>> print(f"Component count: {result['component_count']}")
+
+        Raises:
+            FileNotFoundError: If kicad-cli is not available
+            RuntimeError: If BOM export fails
+        """
+        from ..kicad.bom_exporter import BOMExporter
+
+        # Determine project name
+        if project_name is None:
+            project_name = self.name
+
+        # Determine output file
+        if output_file is None:
+            output_path = Path(project_name)
+            output_file = output_path / f"{project_name}.csv"
+        else:
+            output_file = Path(output_file)
+
+        try:
+            # Generate KiCad project if needed
+            project_path = Path(project_name).resolve()
+            project_base_name = self.name
+            sch_file = project_path / f"{project_base_name}.kicad_sch"
+
+            if not sch_file.exists():
+                context_logger.info(
+                    "Generating KiCad project for BOM export",
+                    component="CIRCUIT",
+                    circuit_name=self.name,
+                    project_name=project_name,
+                )
+
+                project_result = self.generate_kicad_project(
+                    project_name=project_name,
+                    generate_pcb=False,  # Only need schematic for BOM
+                )
+
+                if not project_result.get("success"):
+                    error_msg = f"Failed to generate KiCad project: {project_result.get('error')}"
+                    context_logger.error(
+                        error_msg, component="CIRCUIT", project_name=project_name
+                    )
+                    return {"success": False, "error": error_msg}
+
+            else:
+                context_logger.debug(
+                    "Using existing KiCad project for BOM export",
+                    component="CIRCUIT",
+                    project_path=str(project_path),
+                )
+
+            # Export BOM using kicad-cli
+            context_logger.info(
+                "Exporting BOM",
+                component="CIRCUIT",
+                schematic_file=str(sch_file),
+                output_file=str(output_file),
+            )
+
+            bom_result = BOMExporter.export_csv(
+                schematic_file=sch_file,
+                output_file=output_file,
+                fields=fields,
+                labels=labels,
+                group_by=group_by,
+                exclude_dnp=exclude_dnp,
+            )
+
+            # Add project path to result
+            bom_result["project_path"] = project_path
+
+            return bom_result
+
+        except FileNotFoundError as e:
+            error_msg = f"Cannot export BOM: {e}"
+            context_logger.error(error_msg, component="CIRCUIT")
+            return {"success": False, "error": error_msg}
+
+        except Exception as e:
+            error_msg = f"Failed to generate BOM: {e}"
+            context_logger.error(
+                error_msg, component="CIRCUIT", exception=str(e)
+            )
+            return {"success": False, "error": error_msg}
+
+    def generate_pdf_schematic(
+        self,
+        output_file: Optional[str] = None,
+        project_name: Optional[str] = None,
+        black_and_white: bool = False,
+        theme: Optional[str] = None,
+        exclude_drawing_sheet: bool = False,
+        pages: Optional[str] = None,
+    ) -> Dict[str, Any]:
+        """
+        Generate a PDF schematic from this circuit.
+
+        This method creates a KiCad project if one doesn't already exist, then
+        exports the schematic to a PDF file using kicad-cli.
+
+        Args:
+            output_file: Path where PDF should be written. If not provided,
+                        defaults to {project_name}/{project_name}.pdf
+            project_name: Name of the KiCad project directory. If not provided,
+                         defaults to the circuit name.
+            black_and_white: Export in black and white instead of color (default: False)
+            theme: Color theme to use for export (optional). Theme name depends on KiCad installation.
+            exclude_drawing_sheet: Exclude the drawing sheet/border from PDF (default: False)
+            pages: Page range to export (e.g., "1,3-5" for pages 1, 3, 4, 5).
+                  If not specified, all pages are exported.
+
+        Returns:
+            dict: Result dictionary containing:
+                - success (bool): True if PDF was successfully generated
+                - file (Path): Path to the generated PDF file
+                - project_path (Path): Path to the KiCad project directory
+                - error (str, optional): Error message if generation failed
+
+        Example:
+            >>> circuit = led_blinker()
+            >>> result = circuit.generate_pdf_schematic(project_name="led_blinker")
+            >>> print(f"PDF exported to: {result['file']}")
+
+        Raises:
+            FileNotFoundError: If kicad-cli is not available
+            RuntimeError: If PDF export fails
+        """
+        from ..kicad.pdf_exporter import PDFExporter
+
+        # Determine project name
+        if project_name is None:
+            project_name = self.name
+
+        # Determine output file
+        if output_file is None:
+            output_path = Path(project_name)
+            output_file = output_path / f"{project_name}.pdf"
+        else:
+            output_file = Path(output_file)
+
+        try:
+            # Generate KiCad project if needed
+            project_path = Path(project_name).resolve()
+            project_base_name = self.name
+            sch_file = project_path / f"{project_base_name}.kicad_sch"
+
+            if not sch_file.exists():
+                context_logger.info(
+                    "Generating KiCad project for PDF export",
+                    component="CIRCUIT",
+                    circuit_name=self.name,
+                    project_name=project_name,
+                )
+
+                project_result = self.generate_kicad_project(
+                    project_name=project_name,
+                    generate_pcb=False,  # Only need schematic for PDF
+                )
+
+                if not project_result.get("success"):
+                    error_msg = f"Failed to generate KiCad project: {project_result.get('error')}"
+                    context_logger.error(
+                        error_msg, component="CIRCUIT", project_name=project_name
+                    )
+                    return {"success": False, "error": error_msg}
+
+            else:
+                context_logger.debug(
+                    "Using existing KiCad project for PDF export",
+                    component="CIRCUIT",
+                    project_path=str(project_path),
+                )
+
+            # Export PDF using kicad-cli
+            context_logger.info(
+                "Exporting PDF schematic",
+                component="CIRCUIT",
+                schematic_file=str(sch_file),
+                output_file=str(output_file),
+            )
+
+            pdf_result = PDFExporter.export_pdf(
+                schematic_file=sch_file,
+                output_file=output_file,
+                black_and_white=black_and_white,
+                theme=theme,
+                exclude_drawing_sheet=exclude_drawing_sheet,
+                pages=pages,
+            )
+
+            # Add project path to result
+            pdf_result["project_path"] = project_path
+
+            return pdf_result
+
+        except FileNotFoundError as e:
+            error_msg = f"Cannot export PDF: {e}"
+            context_logger.error(error_msg, component="CIRCUIT")
+            return {"success": False, "error": error_msg}
+
+        except Exception as e:
+            error_msg = f"Failed to generate PDF schematic: {e}"
+            context_logger.error(
+                error_msg, component="CIRCUIT", exception=str(e)
+            )
+            return {"success": False, "error": error_msg}
+
+    def generate_gerbers(
+        self,
+        output_dir: Optional[str] = None,
+        project_name: Optional[str] = None,
+        include_drill: bool = True,
+        drill_format: str = "excellon",
+    ) -> Dict[str, Any]:
+        """
+        Generate Gerber files for PCB manufacturing from this circuit.
+
+        This method creates a complete KiCad project (including PCB) if one doesn't
+        already exist, then exports Gerber files for manufacturing using kicad-cli.
+        Gerbers can be submitted directly to manufacturers like JLCPCB, PCBWay, etc.
+
+        Args:
+            output_dir: Directory where Gerber files should be written. If not provided,
+                       defaults to {project_name}/gerbers
+            project_name: Name of the KiCad project directory. If not provided,
+                         defaults to the circuit name.
+            include_drill: Also export drill files along with Gerbers (default: True)
+            drill_format: Format for drill files: "excellon" (default) or "gerber"
+
+        Returns:
+            dict: Result dictionary containing:
+                - success (bool): True if Gerbers were successfully generated
+                - gerber_files (list): List of Path objects to generated .gbr files
+                - drill_files (tuple): Tuple of (plated_holes_file, non_plated_holes_file) or None
+                - project_path (Path): Path to the KiCad project directory
+                - output_dir (Path): Directory where Gerbers were exported
+                - error (str, optional): Error message if generation failed
+
+        Example:
+            >>> circuit = esp32_board()
+            >>> result = circuit.generate_gerbers(project_name="esp32_board")
+            >>> print(f"Gerbers exported to: {result['output_dir']}")
+            >>> print(f"Files: {len(result['gerber_files'])} Gerber files")
+
+        Requirements:
+            - KiCad 8.0 or later
+            - kicad-cli must be available in PATH
+            - Circuit must be complete with all components and connections
+
+        Notes:
+            - First run generates full KiCad project including PCB (slower)
+            - Subsequent runs reuse existing project (faster)
+            - Default layers: F.Cu, B.Cu, F.Mask, B.Mask, F.SilkS, B.SilkS, F.Paste, B.Paste, Edge.Cuts
+            - Gerbers use standard Protel file extension format (.gbr, .gbl, etc.)
+            - Compatible with JLCPCB, PCBWay, OSH Park, and most PCB manufacturers
+        """
+        # Determine project name
+        if project_name is None:
+            project_name = self.name
+
+        # Determine output directory
+        if output_dir is None:
+            output_path = Path(project_name) / "gerbers"
+        else:
+            output_path = Path(output_dir)
+
+        try:
+            # Generate full KiCad project (including PCB) if needed
+            project_path = Path(project_name).resolve()
+            project_base_name = self.name
+            pcb_file = project_path / f"{project_base_name}.kicad_pcb"
+
+            if not pcb_file.exists():
+                context_logger.info(
+                    "Generating complete KiCad project for Gerber export",
+                    component="CIRCUIT",
+                    circuit_name=self.name,
+                    project_name=project_name,
+                )
+
+                project_result = self.generate_kicad_project(
+                    project_name=project_name,
+                    generate_pcb=True,  # Need PCB for Gerber export
+                )
+
+                if not project_result.get("success"):
+                    error_msg = f"Failed to generate KiCad project: {project_result.get('error')}"
+                    context_logger.error(
+                        error_msg, component="CIRCUIT", project_name=project_name
+                    )
+                    return {"success": False, "error": error_msg}
+
+            else:
+                context_logger.debug(
+                    "Using existing KiCad project for Gerber export",
+                    component="CIRCUIT",
+                    project_path=str(project_path),
+                )
+
+            # Create output directory
+            output_path.mkdir(parents=True, exist_ok=True)
+
+            context_logger.info(
+                "Exporting Gerber files",
+                component="CIRCUIT",
+                pcb_file=str(pcb_file),
+                output_dir=str(output_path),
+            )
+
+            # Import PCB utilities for Gerber export
+            from ..pcb.kicad_cli import get_kicad_cli
+
+            cli = get_kicad_cli()
+
+            # Export Gerbers with standard layer set
+            standard_layers = [
+                "F.Cu",          # Front copper
+                "B.Cu",          # Back copper
+                "F.Mask",        # Front solder mask
+                "B.Mask",        # Back solder mask
+                "F.SilkS",       # Front silkscreen
+                "B.SilkS",       # Back silkscreen
+                "F.Paste",       # Front solder paste
+                "B.Paste",       # Back solder paste
+                "Edge.Cuts",     # Board outline
+            ]
+
+            gerber_files = cli.export_gerbers(
+                pcb_file=pcb_file,
+                output_dir=output_path,
+                layers=standard_layers,
+                protel_extensions=True,  # Use .gbr, .gbl format for compatibility
+            )
+
+            context_logger.info(
+                "Gerber export successful",
+                component="CIRCUIT",
+                gerber_count=len(gerber_files),
+                output_dir=str(output_path),
+            )
+
+            # Export drill files if requested
+            drill_files = None
+            if include_drill:
+                context_logger.debug(
+                    "Exporting drill files",
+                    component="CIRCUIT",
+                    format=drill_format,
+                )
+
+                drill_files = cli.export_drill(
+                    pcb_file=pcb_file,
+                    output_dir=output_path,
+                    format=drill_format,
+                    units="mm",
+                )
+
+            return {
+                "success": True,
+                "gerber_files": gerber_files,
+                "drill_files": drill_files,
+                "project_path": project_path,
+                "output_dir": output_path,
+            }
+
+        except Exception as e:
+            error_msg = f"Failed to generate Gerbers: {e}"
+            context_logger.error(
+                error_msg, component="CIRCUIT", exception=str(e)
+            )
+            return {"success": False, "error": error_msg}
+
     def simulate(self):
         """
         Create a simulator instance for this circuit.
@@ -813,18 +1276,6 @@ class Circuit:
         """
         return self.simulate()
 
-    @property
-    def components(self):
-        """
-        Return a list of all components in this circuit.
-
-        This property provides access to components as a list, which is expected
-        by many parts of the codebase that iterate over circuit.components.
-
-        Returns:
-            List[Component]: List of all components in this circuit
-        """
-        return list(self._components.values())
 
     @property
     def nets(self):
