@@ -84,10 +84,17 @@ class CircuitDataLoader:
 
             # Collect nets from this circuit level
             nets = circuit.get("nets", {})
-            for net_name, net_connections in nets.items():
+            for net_name, net_data in nets.items():
                 if net_name not in flattened_nets:
                     flattened_nets[net_name] = []
 
+                # Handle both formats: list of connections OR dict with nodes key
+                if isinstance(net_data, dict):
+                    # Changed from "connections" to "nodes" for KiCad compatibility
+                    net_connections = net_data.get("nodes", net_data.get("connections", []))  # Fall back to "connections" for backward compatibility
+                else:
+                    net_connections = net_data  # Old format: just a list
+
                 # Update component references in net connections to include prefix
                 for connection in net_connections:
                     if isinstance(connection, dict) and "component" in connection:
@@ -191,9 +198,16 @@ class CircuitReconstructor:
             # Reconstruct nets - ONLY for this circuit level (not subcircuits)
             nets_data = circuit_data.get("nets", {})
 
-            for net_name, connections in nets_data.items():
-                # Creating net with connections (verbose logging available if needed)
+            for net_name, net_info in nets_data.items():
+                # Handle both old format (list) and new format (dict with metadata)
+                if isinstance(net_info, list):
+                    # Old format: just nodes as direct list
+                    connections = net_info
+                else:
+                    # New format: dict with nodes and metadata (changed from "connections" to "nodes" for KiCad compatibility)
+                    connections = net_info.get("nodes", net_info.get("connections", []))  # Fall back to "connections" for backward compatibility
 
+                # Creating net with connections (verbose logging available if needed)
                 net = Net(net_name)
                 # Store net directly in internal storage since add_net may not exist
                 temp_circuit._nets[net_name] = net
