@@ -14,11 +14,14 @@ from collections import defaultdict
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
-from circuit_synth.core.circuit import Circuit
 import kicad_sch_api as ksa
-from circuit_synth.pcb import PCBBoard
+from kicad_pcb_api import PCBBoard
+from kicad_pcb_api.core.types import Net
 
-# Removed duplicate PCB API imports - using single implementation
+from circuit_synth.core.circuit import Circuit
+
+# Removed duplicate PCB API imports - using kicad-pcb-api
+# TODO: Port simple_ratsnest to kicad-pcb-api or keep as circuit-synth extension
 from circuit_synth.pcb.simple_ratsnest import add_ratsnest_to_pcb
 
 logger = logging.getLogger(__name__)
@@ -67,7 +70,8 @@ class PCBGenerator:
         max_height = 0.0
         component_count = 0
 
-        for fp in pcb.footprints.values():
+        # kicad-pcb-api: FootprintCollection supports iteration directly
+        for fp in pcb.footprints:
             # Combine library and name for full footprint identifier
             fp_full_name = f"{fp.library}:{fp.name}"
 
@@ -182,6 +186,18 @@ class PCBGenerator:
         Returns:
             True if successful, False otherwise
         """
+        # Validate placement algorithm (kicad-pcb-api only supports: hierarchical, spiral)
+        SUPPORTED_ALGORITHMS = {"hierarchical", "spiral"}
+        DEFAULT_ALGORITHM = "hierarchical"
+
+        if placement_algorithm not in SUPPORTED_ALGORITHMS:
+            logger.warning(
+                f"⚠️  Unknown placement algorithm '{placement_algorithm}'.\n"
+                f"   Supported algorithms: {', '.join(sorted(SUPPORTED_ALGORITHMS))}\n"
+                f"   Using default: '{DEFAULT_ALGORITHM}'"
+            )
+            placement_algorithm = DEFAULT_ALGORITHM
+
         retry_count = 0
         max_retries = 10
         pcb = None
@@ -195,8 +211,19 @@ class PCBGenerator:
             # Extract components from schematics
             components = self._extract_components_from_schematics()
             if not components:
-                logger.warning("No components found in schematics")
-                return False
+                logger.info("No components found in schematics - generating blank PCB")
+                # Generate blank PCB with default board settings
+                pcb.set_board_outline_rect(0, 0, 100.0, 100.0)  # Default blank board
+                logger.debug("Created blank PCB with default 100x100mm board")
+
+                # Save blank PCB file
+                pcb.save(self.pcb_path)
+                logger.info(f"✓ Blank PCB file saved to: {self.pcb_path}")
+
+                # Update project file to include PCB
+                self._update_project_file()
+
+                return True
 
             logger.debug(f"Found {len(components)} components to place")
 
@@ -263,7 +290,8 @@ class PCBGenerator:
 
                     # Reset component positions before retry
                     if retry_count > 0:
-                        for fp in pcb.footprints.values():
+                        # kicad-pcb-api: FootprintCollection supports iteration directly
+                        for fp in pcb.footprints:
                             fp.position = Point(50, 50)
 
                     # Debug: List components before placement
@@ -298,12 +326,7 @@ class PCBGenerator:
                             group_spacing=group_spacing,
                             board_width=current_width,
                             board_height=current_height,
-                            connections=(
-                                connections
-                                if placement_algorithm
-                                in ["force_directed", "connection_centric", "external"]
-                                else None
-                            ),
+                            connections=None,  # kicad-pcb-api handles connections internally
                         )
 
                     # If we get here, placement was successful
@@ -322,7 +345,8 @@ class PCBGenerator:
                         max_y = max(fp.position.y for fp in footprints) + margin
                         return min_x, min_y, max_x, max_y
 
-                    footprints = list(pcb.footprints.values())
+                    # kicad-pcb-api: FootprintCollection supports iteration directly
+                    footprints = list(pcb.footprints)
                     min_x, min_y, max_x, max_y = calculate_placement_bbox(
                         footprints, margin=10.0
                     )
@@ -338,7 +362,9 @@ class PCBGenerator:
                             f"✓ Adjusted board size to actual needs: {actual_width}x{actual_height}mm"
                         )
                     else:
-                        logger.debug("Skipping board outline recalculation for external placement to preserve cutout")
+                        logger.debug(
+                            "Skipping board outline recalculation for external placement to preserve cutout"
+                        )
 
                     # Debug: Check result and list components after placement
                     logger.debug(f"Placement result: {result}")
@@ -587,10 +613,20 @@ class PCBGenerator:
                 try:
                     schematic = ksa.Schematic.load(str(sch_file))
 
-                    # Extract nets from schematic
-                    for net in schematic.nets:
-                        if len(net.nodes) >= 2:
-                            net_name = net.name
+                    # Extract nets from schematic (stored in internal _data dict)
+                    # Note: ksa.Schematic doesn't expose a .nets property, use _data instead
+                    schematic_nets = schematic._data.get('nets', [])
+
+                    for net in schematic_nets:
+                        if isinstance(net, dict):
+                            net_name = net.get('name')
+                            net_nodes = net.get('nodes', [])
+                        else:
+                            # Fallback for object representation
+                            net_name = getattr(net, 'name', None)
+                            net_nodes = getattr(net, 'nodes', [])
+
+                        if net_name and len(net_nodes) >= 2:
                             # Skip power nets
                             if net_name in ["GND", "3V3", "5V", "VCC", "VDD", "VSS"]:
                                 continue
@@ -598,11 +634,13 @@ class PCBGenerator:
                             if net_name not in nets:
                                 nets[net_name] = set()
 
-                            for node in net.nodes:
-                                nets[net_name].add(node.component_ref)
+                            for node in net_nodes:
+                                ref = node.get('ref') if isinstance(node, dict) else getattr(node, 'ref', None)
+                                if ref:
+                                    nets[net_name].add(ref)
 
                 except Exception as e:
-                    logger.error(f"Error extracting connections from {sch_file}: {e}")
+                    logger.debug(f"Note: Could not extract connections from {sch_file}: {e}")
                     continue
 
         # Convert nets to connection pairs
@@ -856,7 +894,7 @@ class PCBGenerator:
                             # Create new net
                             net_num = len(pcb.pcb_data["nets"])
                             # Simplified - create basic net structure
-                            from circuit_synth.pcb.types import Net
+                            # Net is already imported at top of file from kicad_pcb_api.core.types
 
                             new_net = Net(number=net_num, name=unconnected_net_name)
                             pcb.pcb_data["nets"].append(new_net)
