@@ -57,9 +57,32 @@ class Net:
         self.name = name
         # Each connection is a tuple (comp_ref, pin_number).
         self.connections: List[tuple] = []
+        # Power net properties
+        self.is_power = False
+        self.power_symbol = None
+        self.trace_current = None
+        self.impedance = None
+        self.properties = {}
+
+    @staticmethod
+    def from_dict(data: Dict[str, Any]) -> "Net":
+        """Create Net from dictionary representation."""
+        net = Net(data.get("name", ""))
+        net.is_power = data.get("is_power", False)
+        net.power_symbol = data.get("power_symbol")
+        net.trace_current = data.get("trace_current")
+        net.impedance = data.get("impedance")
+        net.properties = data.get("properties", {})
+        return net
 
     def __repr__(self):
-        return f"Net(name='{self.name}', connections={self.connections})"
+        flags = []
+        if self.is_power:
+            flags.append("power")
+        if self.impedance:
+            flags.append(f"{self.impedance}Ω")
+        flag_str = f" [{', '.join(flags)}]" if flags else ""
+        return f"Net(name='{self.name}'{flag_str}, connections={self.connections})"
 
 
 class Circuit:
@@ -186,7 +209,17 @@ def _parse_circuit(circ_data: dict, sub_dict: Dict[str, Circuit]) -> Circuit:
         value = comp_dict.get("value", symbol_id.split(":")[-1])
         footprint = comp_dict.get("footprint", "")
 
-        # Create SchematicSymbol directly
+        # Extract ALL properties (system + user) using property_utils
+        from ..property_utils import extract_component_properties, extract_dnp_value
+
+        properties = extract_component_properties(comp_dict, default_hierarchy_path="/"  if not hasattr(circuit, 'hierarchical_path') else circuit.hierarchical_path)
+
+        # Handle DNP special case: KiCad has built-in dnp attribute
+        dnp_value = extract_dnp_value(comp_dict)
+
+        # Create SchematicSymbol with properties
+        # NOTE: kicad-sch-api SchematicSymbol doesn't support dnp parameter yet
+        # DNP is written as a property for now. in_bom/on_board flags can be set based on DNP.
         comp = SchematicSymbol(
             reference=ref,
             value=value,
@@ -194,9 +227,11 @@ def _parse_circuit(circ_data: dict, sub_dict: Dict[str, Circuit]) -> Circuit:
             position=Point(0.0, 0.0),  # Will be set during placement
             rotation=0.0,
             footprint=footprint,
-            properties={"hierarchy_path": "/"},  # default top-level
+            properties=properties,  # FIXED: Use extracted properties instead of hardcoded
             pins=[],
             uuid=str(uuid_module.uuid4()),
+            in_bom=not dnp_value,  # If DNP, exclude from BOM
+            on_board=not dnp_value,  # If DNP, exclude from board
         )
 
         # Parse pins and convert to SchematicPin
@@ -207,7 +242,9 @@ def _parse_circuit(circ_data: dict, sub_dict: Dict[str, Circuit]) -> Circuit:
                 name=p.get("name", ""),
                 pin_type=p.get("func", "passive"),  # Changed from 'type' to 'pin_type'
                 position=Point(float(p.get("x", 0)), float(p.get("y", 0))),
-                rotation=float(p.get("orientation", 0)),  # Changed from 'orientation' to 'rotation'
+                rotation=float(
+                    p.get("orientation", 0)
+                ),  # Changed from 'orientation' to 'rotation'
             )
             comp.pins.append(pin_obj)
 
@@ -215,8 +252,29 @@ def _parse_circuit(circ_data: dict, sub_dict: Dict[str, Circuit]) -> Circuit:
 
     # Parse nets
     nets_data = circ_data.get("nets", {})
-    for net_name, connections in nets_data.items():
-        net_obj = Net(net_name)
+    for net_name, net_info in nets_data.items():
+        # Handle both old format (list of connections) and new format (dict with metadata)
+        if isinstance(net_info, list):
+            # Old format: just connections
+            connections = net_info
+            net_obj = Net.from_dict({"name": net_name})  # Use from_dict for consistency
+        else:
+            # New format: dict with connections and metadata
+            # Fixed for Issue #385: Use "nodes" key instead of "connections" key
+            # The NetlistExporter uses "nodes" for KiCad compatibility
+            connections = net_info.get("nodes", net_info.get("connections", []))
+            # Create Net with metadata using from_dict
+            net_dict = {
+                "name": net_name,
+                "is_power": net_info.get("is_power", False),
+                "power_symbol": net_info.get("power_symbol"),
+                "trace_current": net_info.get("trace_current"),
+                "impedance": net_info.get("impedance"),
+                "properties": net_info.get("properties", {}),
+            }
+            net_obj = Net.from_dict(net_dict)
+
+        # Parse connections and add them to the net
         for conn in connections:
             comp_ref = conn["component"]
             pin_data = conn["pin"]
