@@ -52,11 +52,11 @@ class LLMPlacementManager:
         return placements
 
 
-# Use optimized symbol cache from core.component for better performance
-from circuit_synth.core.component import SymbolLibCache
-from circuit_synth.kicad.canonical import CanonicalCircuit, CircuitMatcher
 import kicad_sch_api as ksa
 from kicad_sch_api.core.types import Point
+
+# Use optimized symbol cache for better performance
+from circuit_synth.kicad.canonical import CanonicalCircuit, CircuitMatcher
 from circuit_synth.kicad.kicad_symbol_cache import SymbolLibCache
 
 from .symbol_geometry import SymbolBoundingBoxCalculator
@@ -390,14 +390,20 @@ class SchematicGenerator:
         logger.debug(f"🔍 _check_existing_project:")
         logger.debug(f"   project_dir: {self.project_dir}")
         logger.debug(f"   project_name: {self.project_name}")
-        logger.debug(f"   Checking .kicad_pro: {kicad_pro_file} -> exists={kicad_pro_file.exists()}")
-        logger.debug(f"   Checking .kicad_sch: {kicad_sch_file} -> exists={kicad_sch_file.exists()}")
+        logger.debug(
+            f"   Checking .kicad_pro: {kicad_pro_file} -> exists={kicad_pro_file.exists()}"
+        )
+        logger.debug(
+            f"   Checking .kicad_sch: {kicad_sch_file} -> exists={kicad_sch_file.exists()}"
+        )
 
         # Both files must exist for a valid project
         project_exists = kicad_pro_file.exists()
         schematic_exists = kicad_sch_file.exists() or root_sch_file.exists()
 
-        logger.debug(f"   Result: project_exists={project_exists}, schematic_exists={schematic_exists}")
+        logger.debug(
+            f"   Result: project_exists={project_exists}, schematic_exists={schematic_exists}"
+        )
 
         if project_exists and schematic_exists:
             return True
@@ -419,7 +425,7 @@ class SchematicGenerator:
         return False
 
     def _update_existing_project(
-        self, json_file: str, draw_bounding_boxes: bool = False
+        self, json_file: str, draw_bounding_boxes: bool = False, preserve_user_components: bool = False
     ):
         """Update existing project using synchronizer to preserve manual work"""
         logger.info("🔄 Updating existing project while preserving your work...")
@@ -431,6 +437,7 @@ class SchematicGenerator:
                 HierarchicalSynchronizer,
             )
             from circuit_synth.kicad.schematic.sync_adapter import SyncAdapter
+
             logger.debug("   Synchronizers imported successfully")
         except Exception as e:
             logger.error(f"   Failed to import synchronizers: {e}")
@@ -453,7 +460,14 @@ class SchematicGenerator:
         # Check if this is a hierarchical project
         # Note: sub_dict always includes the main circuit, so check if there's more than one
         has_subcircuits = len(sub_dict) > 1
-        logger.debug(f"Project has {len(sub_dict)} circuits: {'hierarchical' if has_subcircuits else 'flat'}")
+        logger.debug(
+            f"Project has {len(sub_dict)} circuits: {'hierarchical' if has_subcircuits else 'flat'}"
+        )
+
+        # Use the preserve_user_components parameter
+        preserve_components = preserve_user_components
+        if preserve_components:
+            logger.info("⚠️  preserve_user_components=True: Components in KiCad but not in Python will be kept")
 
         if has_subcircuits:
             # Use hierarchical synchronizer for projects with subcircuits
@@ -461,7 +475,7 @@ class SchematicGenerator:
                 f"Detected hierarchical project with {len(sub_dict)} subcircuits"
             )
             synchronizer = HierarchicalSynchronizer(
-                project_path=str(project_path), preserve_user_components=True
+                project_path=str(project_path), preserve_user_components=preserve_components
             )
             # Show hierarchy info
             logger.info(synchronizer.get_hierarchy_info())
@@ -469,7 +483,7 @@ class SchematicGenerator:
             # Use regular synchronizer for flat projects
             logger.debug(f"Creating synchronizer for flat project")
             synchronizer = SyncAdapter(
-                project_path=str(project_path), preserve_user_components=True
+                project_path=str(project_path), preserve_user_components=preserve_components
             )
 
         # Perform synchronization
@@ -492,6 +506,29 @@ class SchematicGenerator:
         # Log results
         self._log_sync_results(sync_report)
 
+        # Synchronize PCB after schematic sync
+        logger.info("🔄 Synchronizing PCB with updated schematic...")
+        try:
+            from circuit_synth.kicad.pcb_gen.pcb_synchronizer import PCBSynchronizer
+
+            pcb_path = self.project_dir / f"{self.project_name}.kicad_pcb"
+            if pcb_path.exists():
+                logger.info("📋 PCB file exists - using synchronizer to preserve manual placement")
+                pcb_sync = PCBSynchronizer(
+                    pcb_path=str(pcb_path),
+                    project_dir=self.project_dir,
+                    project_name=self.project_name
+                )
+                pcb_sync_report = pcb_sync.sync_with_schematics()
+                logger.info("✅ PCB synchronization complete!")
+            else:
+                logger.info("ℹ️  No PCB file found - skipping PCB sync")
+        except Exception as e:
+            logger.error(f"❌ PCB synchronization failed: {e}")
+            logger.warning("   PCB may not reflect latest schematic changes")
+            import traceback
+            traceback.print_exc()
+
         return sync_report
 
     def _log_sync_results(self, sync_report):
@@ -563,26 +600,28 @@ class SchematicGenerator:
             project_name = sch_file.stem
 
             # Read the schematic file
-            content = sch_file.read_text(encoding='utf-8')
+            content = sch_file.read_text(encoding="utf-8")
 
             # Fix empty (project blocks by adding the project name
             # Pattern: (project\n\t\t\t(path -> (project "ProjectName"\n\t\t\t(path
-            pattern = r'(\(project)\n(\s+)\(path'
+            pattern = r"(\(project)\n(\s+)\(path"
             replacement = rf'\1 "{project_name}"\n\2(path'
 
             fixed_content = re.sub(pattern, replacement, content)
 
             # Count how many fixes were made in this file
-            fixes = content.count('(project\n')
+            fixes = content.count("(project\n")
 
             if fixes > 0:
                 logger.info(f"  Fixed {fixes} empty project names in {sch_file.name}")
                 # Write the fixed content back
-                sch_file.write_text(fixed_content, encoding='utf-8')
+                sch_file.write_text(fixed_content, encoding="utf-8")
                 total_fixes += fixes
 
         if total_fixes > 0:
-            logger.info(f"✅ Fixed {total_fixes} total empty project names across {len(schematic_files)} files")
+            logger.info(
+                f"✅ Fixed {total_fixes} total empty project names across {len(schematic_files)} files"
+            )
         else:
             logger.debug("No empty project names found")
 
@@ -605,7 +644,9 @@ class SchematicGenerator:
             logger.info(f"Loading schematic: {sch_path}")
             schematic = ksa.load_schematic(str(sch_path))
 
-            logger.info(f"Adding bounding boxes for {len(schematic.components)} components")
+            logger.info(
+                f"Adding bounding boxes for {len(schematic.components)} components"
+            )
 
             # Use kicad-sch-api's built-in method to draw all component bounding boxes
             schematic.draw_component_bounding_boxes()
@@ -623,7 +664,8 @@ class SchematicGenerator:
         json_file: str,
         force_regenerate: bool = False,
         generate_pcb: bool = True,
-        placement_algorithm: str = "connection_centric",
+        force_pcb_regenerate: bool = False,
+        placement_algorithm: str = "hierarchical",
         schematic_placement: str = "connection_aware",
         draw_bounding_boxes: bool = False,
         **pcb_kwargs,
@@ -635,11 +677,14 @@ class SchematicGenerator:
             json_file: Path to circuit JSON file
             force_regenerate: If True, recreate project even if it exists (loses manual work!)
             generate_pcb: If True, generate PCB along with schematics (default: True)
-            placement_algorithm: PCB placement algorithm to use (hierarchical, force_directed, connection_centric, advanced, external)
+            force_pcb_regenerate: If True, regenerate PCB from scratch (loses manual placement!)
+            placement_algorithm: PCB placement algorithm to use (hierarchical, spiral)
             schematic_placement: Schematic placement algorithm - "sequential" or "connection_aware" (default: "sequential")
             **pcb_kwargs: Additional keyword arguments passed to PCB generation
         """
-        logger.debug(f"🚀 generate_project() called: force_regenerate={force_regenerate}")
+        logger.debug(
+            f"🚀 generate_project() called: force_regenerate={force_regenerate}"
+        )
 
         # Check if project already exists
         project_exists = self._check_existing_project()
@@ -655,24 +700,26 @@ class SchematicGenerator:
             )
 
             try:
-                result = self._update_existing_project(json_file, draw_bounding_boxes)
+                preserve_components = pcb_kwargs.get('preserve_user_components', False)
+                if preserve_components:
+                    logger.info("⚠️  preserve_user_components=True: Components in KiCad but not in Python will be kept")
+                result = self._update_existing_project(json_file, draw_bounding_boxes, preserve_components)
                 return result
             except Exception as e:
                 print(f"🔥 Exception type: {type(e).__name__}")
                 print(f"🔥 Exception message: {e}")
                 import traceback
+
                 print(f"🔥 Traceback:")
                 traceback.print_exc()
-                print("="*80 + "\n")
+                print("=" * 80 + "\n")
                 logger.error(f"❌ Update failed: {e}")
                 logger.error("   Falling back to regeneration...")
                 # Fall through to regeneration
 
         elif project_exists and force_regenerate:
             # User explicitly wants to regenerate
-            logger.info(
-                f"Force regenerating project at: {self.project_dir}"
-            )
+            logger.info(f"Force regenerating project at: {self.project_dir}")
             logger.info(
                 "   This will LOSE all manual work (component positions, wires, etc.)"
             )
@@ -970,39 +1017,72 @@ class SchematicGenerator:
 
         # Generate PCB (default behavior)
         if generate_pcb:
-            logger.debug("Generating PCB with hierarchical placement...")
             # Import locally to avoid circular import
             from circuit_synth.kicad.pcb_gen import PCBGenerator
+            from circuit_synth.kicad.pcb_gen.pcb_synchronizer import PCBSynchronizer
 
-            pcb_gen = PCBGenerator(self.project_dir, self.project_name)
+            # Check if PCB already exists
+            pcb_path = self.project_dir / f"{self.project_name}.kicad_pcb"
+            pcb_exists = pcb_path.exists()
 
-            # Generate PCB with specified placement algorithm
-            success = pcb_gen.generate_pcb(
-                circuit_dict=sub_dict,
-                placement_algorithm=placement_algorithm,
-                board_width=pcb_kwargs.get(
-                    "board_width", None
-                ),  # Auto-calculate if not specified
-                board_height=pcb_kwargs.get("board_height", None),
-                component_spacing=pcb_kwargs.get("component_spacing", 5.0),
-                group_spacing=pcb_kwargs.get("group_spacing", 10.0),
-                **{
-                    k: v
-                    for k, v in pcb_kwargs.items()
-                    if k
-                    not in [
-                        "board_width",
-                        "board_height",
-                        "component_spacing",
-                        "group_spacing",
-                    ]
-                },
-            )
-
-            if success:
-                logger.info("PCB generation complete!")
+            # Decide whether to sync or regenerate
+            if pcb_exists and not force_pcb_regenerate:
+                # Synchronize existing PCB (preserves manual placement)
+                logger.info("📋 PCB exists - using synchronizer to preserve manual placement")
+                try:
+                    pcb_sync = PCBSynchronizer(
+                        pcb_path=str(pcb_path),
+                        project_dir=self.project_dir,
+                        project_name=self.project_name
+                    )
+                    sync_report = pcb_sync.sync_with_schematics()
+                    logger.info("✅ PCB synchronization complete!")
+                    success = True
+                except Exception as e:
+                    logger.error(f"❌ PCB synchronization failed: {e}")
+                    logger.info("Falling back to full PCB regeneration...")
+                    success = False
+                    pcb_exists = False  # Force regeneration below
             else:
-                logger.error("❌ PCB generation failed!")
+                success = False  # Will generate below
+
+            # Generate PCB if it doesn't exist or sync failed or force_pcb_regenerate
+            if not pcb_exists or force_pcb_regenerate or not success:
+                if force_pcb_regenerate:
+                    logger.warning("⚠️  force_pcb_regenerate=True - regenerating PCB from scratch (manual placement will be lost!)")
+                else:
+                    logger.debug("Generating new PCB with hierarchical placement...")
+
+                pcb_gen = PCBGenerator(self.project_dir, self.project_name)
+
+                # Generate PCB with specified placement algorithm
+                success = pcb_gen.generate_pcb(
+                    circuit_dict=sub_dict,
+                    placement_algorithm=placement_algorithm,
+                    board_width=pcb_kwargs.get(
+                        "board_width", None
+                    ),  # Auto-calculate if not specified
+                    board_height=pcb_kwargs.get("board_height", None),
+                    component_spacing=pcb_kwargs.get("component_spacing", 5.0),
+                    group_spacing=pcb_kwargs.get("group_spacing", 10.0),
+                    **{
+                        k: v
+                        for k, v in pcb_kwargs.items()
+                        if k
+                        not in [
+                            "board_width",
+                            "board_height",
+                            "component_spacing",
+                            "group_spacing",
+                            "preserve_user_components",  # Schematic-only parameter
+                        ]
+                    },
+                )
+
+                if success:
+                    logger.info("PCB generation complete!")
+                else:
+                    logger.error("❌ PCB generation failed!")
 
         # NOTE: Netlist generation now handled earlier in the method using modular service
         logger.debug("Netlist generation completed earlier using modular service")
@@ -1317,23 +1397,37 @@ class SchematicGenerator:
 
                         pin_net_map = {}
                         # Handle both Component (has _pins) and SchematicSymbol (has pins list)
-                        if hasattr(comp, '_pins'):
-                            logger.debug(f"🔍 Using _pins dict, count: {len(comp._pins)}")
+                        if hasattr(comp, "_pins"):
+                            logger.debug(
+                                f"🔍 Using _pins dict, count: {len(comp._pins)}"
+                            )
                             for pin_num, pin in comp._pins.items():
-                                logger.debug(f"🔍   Pin {pin_num}: number={pin.number}, net={pin.net}, net.name={pin.net.name if pin.net else 'None'}")
+                                logger.debug(
+                                    f"🔍   Pin {pin_num}: number={pin.number}, net={pin.net}, net.name={pin.net.name if pin.net else 'None'}"
+                                )
                                 if pin.net:
                                     pin_net_map[pin.number] = pin.net.name
-                                    logger.debug(f"🔍     ✅ Mapped {pin.number} -> {pin.net.name}")
-                        elif hasattr(comp, 'pins'):
+                                    logger.debug(
+                                        f"🔍     ✅ Mapped {pin.number} -> {pin.net.name}"
+                                    )
+                        elif hasattr(comp, "pins"):
                             # SchematicSymbol from kicad-sch-api: pins don't have net information
                             # Net connections are stored separately in the schematic's nets list
                             # For bounding box calculation, we can use an empty pin_net_map
-                            logger.debug(f"🔍 Component has pins list (SchematicSymbol) - skipping net mapping")
-                            logger.debug(f"   (Net info not available on SchematicPin objects from kicad-sch-api)")
+                            logger.debug(
+                                f"🔍 Component has pins list (SchematicSymbol) - skipping net mapping"
+                            )
+                            logger.debug(
+                                f"   (Net info not available on SchematicPin objects from kicad-sch-api)"
+                            )
                             # Leave pin_net_map empty - bounding box will be calculated without net labels
 
-                        logger.debug(f"🔍 FINAL pin_net_map for {comp.reference}: {pin_net_map}")
-                        logger.debug(f"🔍 Calling get_symbol_dimensions with pin_net_map")
+                        logger.debug(
+                            f"🔍 FINAL pin_net_map for {comp.reference}: {pin_net_map}"
+                        )
+                        logger.debug(
+                            f"🔍 Calling get_symbol_dimensions with pin_net_map"
+                        )
 
                         comp_width, comp_height = (
                             SymbolBoundingBoxCalculator.get_symbol_dimensions(
@@ -1729,8 +1823,7 @@ class SchematicGenerator:
     def get_symbol_libraries(self) -> List[str]:
         """Get list of available symbol libraries."""
         try:
-            # Use optimized symbol cache from core.component for better performance
-            from circuit_synth.core.component import SymbolLibCache
+            # Use optimized symbol cache for better performance
             from circuit_synth.kicad.kicad_symbol_cache import SymbolLibCache
 
             cache = SymbolLibCache()
