@@ -56,11 +56,14 @@ class SymbolBoundingBoxCalculator:
             raise ValueError("Symbol data is None or empty")
 
         import sys
+
         # Reduced logging frequency - only log if DEBUG environment variable is set
         debug_enabled = os.getenv("CIRCUIT_SYNTH_DEBUG", "").lower() == "true"
         if debug_enabled:
             print(f"\n=== CALCULATING BOUNDING BOX ===", file=sys.stderr, flush=True)
-            print(f"include_properties={include_properties}", file=sys.stderr, flush=True)
+            print(
+                f"include_properties={include_properties}", file=sys.stderr, flush=True
+            )
 
         min_x = float("inf")
         min_y = float("inf")
@@ -119,8 +122,16 @@ class SymbolBoundingBoxCalculator:
         if min_x == float("inf") or max_x == float("-inf"):
             raise ValueError(f"No valid geometry found in symbol data")
 
-        print(f"After geometry processing: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})", file=sys.stderr, flush=True)
-        print(f"  Width: {max_x - min_x:.2f}, Height: {max_y - min_y:.2f}", file=sys.stderr, flush=True)
+        print(
+            f"After geometry processing: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})",
+            file=sys.stderr,
+            flush=True,
+        )
+        print(
+            f"  Width: {max_x - min_x:.2f}, Height: {max_y - min_y:.2f}",
+            file=sys.stderr,
+            flush=True,
+        )
 
         # Add small margin for text that might extend beyond shapes
         margin = 0.254  # 10 mils
@@ -158,15 +169,26 @@ class SymbolBoundingBoxCalculator:
             f"Calculated bounding box: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})"
         )
 
-        print(f"FINAL BBOX: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})", file=sys.stderr, flush=True)
-        print(f"  Width: {max_x - min_x:.2f}, Height: {max_y - min_y:.2f}", file=sys.stderr, flush=True)
+        print(
+            f"FINAL BBOX: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})",
+            file=sys.stderr,
+            flush=True,
+        )
+        print(
+            f"  Width: {max_x - min_x:.2f}, Height: {max_y - min_y:.2f}",
+            file=sys.stderr,
+            flush=True,
+        )
         print("=" * 50 + "\n", file=sys.stderr, flush=True)
 
         return (min_x, min_y, max_x, max_y)
 
     @classmethod
     def get_symbol_dimensions(
-        cls, symbol_data: Dict[str, Any], include_properties: bool = True, pin_net_map: Optional[Dict[str, str]] = None
+        cls,
+        symbol_data: Dict[str, Any],
+        include_properties: bool = True,
+        pin_net_map: Optional[Dict[str, str]] = None,
     ) -> Tuple[float, float]:
         """
         Get the width and height of a symbol.
@@ -296,11 +318,15 @@ class SymbolBoundingBoxCalculator:
         # If no net name match, use minimal fallback to avoid oversized bounding boxes
         if pin_net_map and pin_number in pin_net_map:
             label_text = pin_net_map[pin_number]
-            print(f"  PIN {pin_number}: ✅ USING NET '{label_text}' (len={len(label_text)}), at=({x:.2f}, {y:.2f}), angle={angle}", file=sys.stderr, flush=True)
+            logger.debug(
+                f"PIN {pin_number}: Using net '{label_text}' (len={len(label_text)}), at=({x:.2f}, {y:.2f}), angle={angle}"
+            )
         else:
             # No net match - use minimal size (3 chars) instead of potentially long pin name
             label_text = "XXX"  # 3-character placeholder for unmatched pins
-            print(f"  PIN {pin_number}: ⚠️  NO MATCH, using minimal fallback (pin name was '{pin_name}'), at=({x:.2f}, {y:.2f})", file=sys.stderr, flush=True)
+            logger.debug(
+                f"PIN {pin_number}: Using fallback sizing (pin name='{pin_name}'), at=({x:.2f}, {y:.2f})"
+            )
 
         if label_text and label_text != "~":  # ~ means no name
             # Calculate text dimensions
@@ -313,7 +339,11 @@ class SymbolBoundingBoxCalculator:
             # For vertical text: height = char_count * char_height (characters stack vertically)
             name_height = len(label_text) * cls.DEFAULT_TEXT_HEIGHT
 
-            print(f"    label_width={name_width:.2f}, label_height={name_height:.2f} (len={len(label_text)})", file=sys.stderr, flush=True)
+            print(
+                f"    label_width={name_width:.2f}, label_height={name_height:.2f} (len={len(label_text)})",
+                file=sys.stderr,
+                flush=True,
+            )
 
             # Adjust bounds based on pin orientation
             # Labels are placed at PIN ENDPOINT with offset, extending AWAY from the component
@@ -323,19 +353,35 @@ class SymbolBoundingBoxCalculator:
 
             if angle == 0:  # Pin points right - label extends LEFT from endpoint
                 label_x = end_x - offset - name_width
-                print(f"    Angle 0 (Right pin): min_x {min_x:.2f} -> {label_x:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                print(
+                    f"    Angle 0 (Right pin): min_x {min_x:.2f} -> {label_x:.2f} (offset={offset:.3f})",
+                    file=sys.stderr,
+                    flush=True,
+                )
                 min_x = min(min_x, label_x)
             elif angle == 180:  # Pin points left - label extends RIGHT from endpoint
                 label_x = end_x + offset + name_width
-                print(f"    Angle 180 (Left pin): max_x {max_x:.2f} -> {label_x:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                print(
+                    f"    Angle 180 (Left pin): max_x {max_x:.2f} -> {label_x:.2f} (offset={offset:.3f})",
+                    file=sys.stderr,
+                    flush=True,
+                )
                 max_x = max(max_x, label_x)
             elif angle == 90:  # Pin points up - label extends DOWN from endpoint
                 label_y = end_y - offset - name_height
-                print(f"    Angle 90 (Up pin): min_y {min_y:.2f} -> {label_y:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                print(
+                    f"    Angle 90 (Up pin): min_y {min_y:.2f} -> {label_y:.2f} (offset={offset:.3f})",
+                    file=sys.stderr,
+                    flush=True,
+                )
                 min_y = min(min_y, label_y)
             elif angle == 270:  # Pin points down - label extends UP from endpoint
                 label_y = end_y + offset + name_height
-                print(f"    Angle 270 (Down pin): max_y {max_y:.2f} -> {label_y:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                print(
+                    f"    Angle 270 (Down pin): max_y {max_y:.2f} -> {label_y:.2f} (offset={offset:.3f})",
+                    file=sys.stderr,
+                    flush=True,
+                )
                 max_y = max(max_y, label_y)
 
         # Pin numbers are typically placed near the component body
@@ -354,5 +400,9 @@ class SymbolBoundingBoxCalculator:
             max_x += margin
             max_y += margin
 
-        print(f"    Pin bounds: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})", file=sys.stderr, flush=True)
+        print(
+            f"    Pin bounds: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})",
+            file=sys.stderr,
+            flush=True,
+        )
         return (min_x, min_y, max_x, max_y)
