@@ -6,7 +6,14 @@ import logging
 from enum import Enum
 from typing import Dict, List, Optional, Tuple
 
-from kicad_sch_api.core.types import Label, LabelType, Point, SchematicSymbol, Text, Wire
+from kicad_sch_api.core.types import (
+    Label,
+    LabelType,
+    Point,
+    SchematicSymbol,
+    Text,
+    Wire,
+)
 
 logger = logging.getLogger(__name__)
 
