@@ -62,7 +62,15 @@ class KiCadParser:
                 if isinstance(sheet_info, list) and len(sheet_info) >= 2:
                     schematic_file, sheet_name = sheet_info[0], sheet_info[1]
                     if sheet_name == "":  # Traditional root sheet has empty name
-                        root_sch_path = self.project_dir / schematic_file
+                        # Check if schematic_file is a UUID (KiCad stores UUIDs, not filenames)
+                        # UUIDs are 36 chars with dashes: xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
+                        if len(schematic_file) == 36 and schematic_file.count('-') == 4:
+                            # It's a UUID, use project name instead
+                            root_sch_path = self.project_dir / f"{self.kicad_project.stem}.kicad_sch"
+                        else:
+                            # It's a filename
+                            root_sch_path = self.project_dir / schematic_file
+
                         if root_sch_path.exists():
                             logger.info(
                                 f"Found traditional root schematic: {root_sch_path}"
@@ -160,7 +168,7 @@ class KiCadParser:
 
         try:
             # Step 1: Generate real KiCad netlist
-            logger.info("🔍 HIERARCHICAL DEBUG: Step 1 - Generating KiCad netlist")
+            logger.debug("🔍 HIERARCHICAL DEBUG: Step 1 - Generating KiCad netlist")
             netlist_path = self.generate_netlist()
             if not netlist_path:
                 logger.warning(
@@ -202,7 +210,7 @@ class KiCadParser:
                 logger.info("  - No hierarchical structure detected")
 
             # Step 3.5: Build hierarchical tree for import relationships
-            logger.info("🔍 HIERARCHICAL DEBUG: Step 3.5 - Building hierarchical tree")
+            logger.debug("🔍 HIERARCHICAL DEBUG: Step 3.5 - Building hierarchical tree")
             hierarchical_tree = self._build_hierarchical_tree(hierarchical_info)
 
             logger.info(f"🔍 HIERARCHICAL DEBUG: Hierarchical tree results:")
@@ -216,7 +224,7 @@ class KiCadParser:
             circuits = {}
 
             if hierarchical_info:
-                logger.info("🔍 HIERARCHICAL DEBUG: Using hierarchical approach")
+                logger.debug("🔍 HIERARCHICAL DEBUG: Using hierarchical approach")
                 # Distribute components across hierarchical sheets based on schematic analysis
                 for sheet_name, sheet_components in hierarchical_info.items():
                     logger.info(
@@ -265,17 +273,17 @@ class KiCadParser:
                         f"🔍 HIERARCHICAL DEBUG: Created {sheet_name}: {len(sheet_actual_components)} components, {len(sheet_nets)} nets"
                     )
             else:
-                logger.info("🔍 HIERARCHICAL DEBUG: Using flat circuit approach")
-                # Single flat circuit
+                logger.debug("🔍 HIERARCHICAL DEBUG: Using flat circuit approach")
+                # Single flat circuit - use project name instead of hardcoded "main"
                 circuit = Circuit(
-                    name="main",
+                    name=self.kicad_project.stem,
                     components=components,
                     nets=nets,
                     schematic_file=f"{self.kicad_project.stem}.kicad_sch",
                     is_hierarchical_sheet=False,
                     hierarchical_tree=hierarchical_tree,
                 )
-                circuits["main"] = circuit
+                circuits[self.kicad_project.stem] = circuit
                 logger.info(
                     f"🔍 HIERARCHICAL DEBUG: Created flat circuit: {len(components)} components, {len(nets)} nets"
                 )
@@ -299,7 +307,7 @@ class KiCadParser:
 
     def _analyze_hierarchical_structure(self) -> Dict[str, List[Component]]:
         """Analyze schematic files to understand hierarchical structure"""
-        logger.info("🔍 HIERARCHICAL DEBUG: Starting _analyze_hierarchical_structure")
+        logger.debug("🔍 HIERARCHICAL DEBUG: Starting _analyze_hierarchical_structure")
         hierarchical_info = {}
 
         # Find all schematic files
@@ -335,9 +343,8 @@ class KiCadParser:
             components, net_names = self._parse_schematic_file(sch_file)
 
             # Determine circuit name and type
+            # Use the schematic file stem as the circuit name
             circuit_name = sch_file.stem
-            if circuit_name == self.kicad_project.stem:
-                circuit_name = "main"
 
             logger.info(
                 f"🔍 HIERARCHICAL DEBUG: Circuit '{circuit_name}' from {sch_file.name}:"
@@ -359,16 +366,15 @@ class KiCadParser:
         self, hierarchical_info: Dict[str, List[Component]]
     ) -> Dict[str, List[str]]:
         """Build a tree structure showing parent-child relationships between sheets"""
-        logger.info("🔍 HIERARCHICAL DEBUG: Building hierarchical tree")
+        logger.debug("🔍 HIERARCHICAL DEBUG: Building hierarchical tree")
         hierarchical_tree = {}
 
         # Find all schematic files and their sheet instances
         schematic_files = list(self.project_dir.glob("*.kicad_sch"))
 
         for sch_file in schematic_files:
+            # Use schematic file stem as circuit name
             circuit_name = sch_file.stem
-            if circuit_name == self.kicad_project.stem:
-                circuit_name = "main"
 
             # Parse this schematic file for sheet instances
             logger.info(
@@ -573,9 +579,8 @@ class KiCadParser:
                     not is_main_schematic and sch_file.stem != "root"
                 )
 
+                # Use schematic file stem as circuit name
                 circuit_name = sch_file.stem
-                if is_main_schematic:
-                    circuit_name = "main"
 
                 circuit = Circuit(
                     name=circuit_name,
